@@ -3,8 +3,6 @@
 
 #include <iosfwd>
 
-#include "../error/error.h"
-#include "../options/options.h"
 #include "../conffile/conffile.h"
 #include "../scenario/scenario.h"
 
@@ -12,10 +10,7 @@ class Analysis
 {
 //data
                                     // for this analysis:
-    Error d_error;                  //  error handling
-    Options d_options;              //  options 
     ConfFile d_confFile;            //  configuration (parameters) file
-
     Scenario d_scenario;            // performs one (1) simulation
 //=
 
