@@ -3,7 +3,8 @@
 
 void Analysis::run()
 {
-    if (d_error.count() != 0)   // errors may be set at Options or ConfFile
+                                // errors may be set at Options or ConfFile
+    if (Error::instance().count() != 0)   
         return;                 // construction
 
     requireBase();              // the base directory must be (made) available
