@@ -6,13 +6,8 @@
 
 #include "../options/options.h"
 
-class Error;
-
 class ConfFile
 {
-    Error &d_error;
-    Options const &d_options;
-    
     mutable FBB::Config d_config;
 
     public:
@@ -20,7 +15,7 @@ class ConfFile
         typedef FBB::Config::CIVect::const_iterator IDiterator;
         typedef std::pair<IDiterator, IDiterator>   IDpair;
 
-        ConfFile(Error &error, Options const &options);
+        ConfFile();
         void load();                                                    // .h
 
                                                 // numeric param., 0 if not
