@@ -11,7 +11,7 @@ size_t ConfFile::value(char const *id) const
     }
     catch (...)
     {
-        d_error(CONFIG, iter->lineNr(), MISSING_NR) << id << "')\n";
+        Error::instance()(CONFIG, iter->lineNr(), MISSING_NR) << id << "')\n";
         return 0;
     }
 }
