@@ -21,8 +21,9 @@ class Costs
                                             // costs of treatments given
     std::vector<CostPair> d_treatment;      // tumor diam.
  
-    double d_discountAge;     
-    uint16_t d_discount;
+    double d_referenceAge;                  // discount reference age
+    double d_discountProportion;
+
     uint16_t d_biop;                        // biopsy cost
 
     static char const s_id[];
@@ -30,31 +31,32 @@ class Costs
     public:
         Costs(Scenario const &scenario);
 
-        double treatment(double age, double diameter) const;        //  .h
-        double screening(double age, uint16_t cost) const;
-        double biopsy(double age) const;
+        double biopsy(double age) const;                            // .h
+        double screening(double age, uint16_t cost) const;          // .h
+        double treatment(double age, double diameter) const;        // .h
 
         void writeParameters(std::ostream &out) const;
 
     private:
         uint16_t cost(double diameter) const;
-        double discount(size_t cost, double age) const;          
+        double discount(double age, size_t cost) const;
 };
 
 
 inline double Costs::biopsy(double age) const
 {
-    return discount(d_biop, age);
+    return discount(age, d_biop);
+}
+
+inline double Costs::screening(double age, uint16_t cost) const
+{
+    return discount(age, cost);
 }
 
 inline double Costs::treatment(double age, double diameter) const
 {
-    return discount(biopsy(age) + cost(diameter), age);
+    return discount(age, biopsy(age) + cost(diameter));
 }
 
-
 #endif
 
-
-
-
