@@ -12,23 +12,26 @@ Costs::Costs(Scenario const &scenario)
         return;        
     }
 
-    istringstream in{ single.iter->tail() };
+    istringstream in{ single.iter->tail() };    // costs-specification
 
-    in >> d_discountAge >> d_discount >> d_biop;
+    in >> d_referenceAge >> d_discountProportion >> d_biop;
 
+    double lastAge = -1;                            // ages must increase
     try
     {
         CostPair spec;
-        while (in >> spec.first)
+        while (in >> spec.first)                    // begin diameter
         {
-            if (not (in.ignore() >> spec.second))
-                throw false;                    // incomplete entry
-            
+            if (spec.first <= lastAge)              // not increasing
+                throw false;
+
+            if (not (in.ignore() >> spec.second))   // followed by treatment
+                throw false;                        // cost. Throws at an
+                                                    // incomplete entry
             d_treatment.push_back(spec);
-
-            xerr("from " << d_treatment.back().first << " to " << d_treatment.back().second);
-
+            lastAge = spec.first;
         }
+
         if (
             d_treatment.size() == 0 
             or 
@@ -43,3 +46,7 @@ Costs::Costs(Scenario const &scenario)
     }
 }
 
+
+// xerr("from " << d_treatment.back().first << " to " << [backslash]
+// d_treatment.back().second);
+
