@@ -5,9 +5,9 @@ void Costs::writeParameters(ostream &out) const
 {
     out << 
         "   costs:\n"
-        "      discount age:    " << d_discountAge << "\n"
-        "      cost discount:   " << d_discount << "\n"
-        "      biopsy costs:    " << d_biop << '\n';
+        "      discount reference age: " << d_referenceAge << "\n"
+        "      discount proportion:    " << d_discountProportion << "\n"
+        "      biopsy costs:           " << d_biop << '\n';
     
     for (size_t idx = 0; idx != d_treatment.size(); ++idx)
         out << 
