@@ -3,10 +3,13 @@
 
 Densities::Densities(Scenario const &scenario)
 :
-    d_error(scenario.error())
+    d_error(Error::instance())
 {
     auto range = scenario.lines(s_id);
 
     for (auto iter = range.pair.first; iter != range.pair.second; ++iter)
-        add(range.src, *iter);
+    {
+        if (not add(range.src, *iter))
+            break;
+    }
 }
