@@ -1,11 +1,11 @@
 //#define XERR
 #include "densities.ih"
 
-Uint16Vect Densities::indices(Random &random, DoubleVect const &ages) const
+Uint16Vect Densities::indices(DoubleVect const &ages) const
 {
     Uint16Vect ret;
 
-    double prob = random.uniform();
+    double prob = Random::instance().uniform();
 
     for (double age: ages)
         ret.push_back(biradsIdx(age, prob));
