@@ -5,16 +5,21 @@
 enum ConfigSrc         
 {
     CONFIG,
-    ANALYSIS
+    ANALYSIS,
+    NO_SRC,
 };
 
 enum Err
 {
+    NO_ERROR,
     COSTS_SIZE,
+    CUMPROB,
+    INCOMPLETE_SPEC,
     INVALID_PROBSUM,
     MISSING_NR,
     MULTIPLY_SPECIFIED,
     N_CARRIERS,
+    NOT_CONSECUTIVE,
     SPECIFICATION,
     TUMORGROWTH_STARTDIAM,
     TUMORGROWTH_AGEGROUPS,
@@ -30,7 +35,7 @@ enum Constants
     EXPONENTIAL,
     NO_DIST,        // no distribution specified
 
-    N_BIRADS = 4,
+    N_BIRADS = 4,   // 4 bi-rad categories (cf. tech man. section Densities)
 
 // -> Modalities
 //    N_DOSES = 4,    // # doses of Modalities
