@@ -1,6 +1,8 @@
 //#define XERR
 #include "error.ih"
 
+    // line nrs 0 are not shown
+
 ostream &Error::operator()(ConfigSrc type, uint16_t lineNr, Err value)
 {
     cerr << "[Error " << src(type);
@@ -8,5 +10,5 @@ ostream &Error::operator()(ConfigSrc type, uint16_t lineNr, Err value)
     if (lineNr != 0)
         cerr << ' ' << lineNr;
 
-    return cerr << "] " << s_error[value];
+    return cerr << "] " << s_errorMsg[value];
 }
