@@ -24,8 +24,14 @@ struct Globals
         static uint16_t xlat(Map const &map, std::string const &key);
         static uint16_t xlatDist(std::string const &key);
 
+                                                    // distIdx must be valid
+                                                    // (unchecked)
+        static std::string const &distName(uint16_t distIdx);
+
         static double findAge(DoubleVect const &cumProb, double prob);
 
+        static double checkStarAge(std::string const &endAge);
+        static bool equal(double value1, double value2);
         static bool isZero(double value);
         static bool isNonNegZero(double value);
         static int weakCompare(double lhs, double rhs); // uses WEAK_TOLERANCE
@@ -34,12 +40,6 @@ struct Globals
                                           uint16_t nDigits);
 };
 
-// static
-inline bool Globals::isZero(double value)
-{
-    return -TOLERANCE <= value and value <= TOLERANCE;
-}
-
 // static
 inline bool Globals::isNonNegZero(double value)
 {
@@ -47,4 +47,3 @@ inline bool Globals::isNonNegZero(double value)
 }
 
 #endif
-
