@@ -28,8 +28,8 @@ bool Growth::ageGroup(ConfigSrc src, uint16_t lineNr, istream &in)
         return true;
     }
 
-    d_error(src, lineNr, MULTIPLY_SPECIFIED) << "agegroup " <<  
-                ag.beginAge() << '-' << ag.endAge() << '\n';
+    Error::instance()(src, lineNr, MULTIPLY_SPECIFIED) << "agegroup " <<  
+                     ag.beginAge() << '-' << ag.endAge() << '\n';
 
     return false;
 }
