@@ -2,8 +2,6 @@
 #include "growth.ih"
 
 Growth::Growth(Scenario const &scenario)
-:
-    d_error(scenario.error())
 {
     auto range = scenario.lines(s_id);
 
@@ -17,11 +15,13 @@ Growth::Growth(Scenario const &scenario)
     if (not ok)
         return;
 
+    Error &error = Error::instance();
+
     if (d_start.dist() == NO_DIST)
-        d_error(range.src, 0, TUMORGROWTH_STARTDIAM);
+        error(range.src, 0, TUMORGROWTH_STARTDIAM);
 
     if (d_ageGroups.empty())
-        d_error(range.src, 0, TUMORGROWTH_AGEGROUPS);
+        error(range.src, 0, TUMORGROWTH_AGEGROUPS);
 }
 
 
