@@ -32,7 +32,7 @@ try
 }
 catch (uint16_t lineNr)
 {
-    d_error(src, lineNr, SPECIFICATION) << s_id << "')\n";
+    Error::instance()(src, lineNr, SPECIFICATION) << s_id << "')\n";
     return false;
 }
 
