@@ -3,7 +3,7 @@
 
 uint16_t Incidence::carrier() const
 {
-    double value = d_random.uniform();
+    double value = Random::instance().uniform();
 
     return find_if(d_cumProb, d_cumProb + END_CARRIERS, 
                 [&](double cumProb)
