@@ -19,11 +19,8 @@
 #include "../vsd/vsd.h"
 #include "../scenario/scenario.h"
 
-class Random;
-
 struct Incidence: public Spread
 {
-    Random &d_random;
     Scenario const &d_scenario;
 
     class Params
@@ -57,7 +54,7 @@ struct Incidence: public Spread
         static char const s_id[];
 
     public:
-        Incidence(Random &random, Scenario const &scenario);
+        Incidence(Scenario const &scenario);
         void refresh();
 
         std::vector<Params> const &params() const;  
