@@ -1,9 +1,8 @@
 //#define XERR
 #include "incidence.ih"
 
-Incidence::Incidence(Random &random, Scenario const &scenario)
+Incidence::Incidence(Scenario const &scenario)
 :
-    d_random(random),
     d_scenario(scenario)
 {
     set();                                  // set the parameters
