@@ -8,9 +8,9 @@ void Incidence::refresh()
         if (params.d_prob < TOLERANCE)
             return;
 
-        params.d_risk.refresh(d_random);
-        params.d_mean.refresh(d_random);
-        params.d_stdDev.refresh(d_random);
+        params.d_risk.refresh();
+        params.d_mean.refresh();
+        params.d_stdDev.refresh();
     }
 
     setTumorRisk();
