@@ -10,7 +10,7 @@ void Loop::checkSeed()
         [[fallthrough]];
 
         case FIXED_SEED:
-            d_random.reset(d_seed);
+            Random::instance().reset(d_seed);
         break;
 
         default:
