@@ -8,11 +8,9 @@ void Loop::initialize(size_t idx)
     d_roundDetected = 0;                    // org: roundDetected
     d_selfDetected = false;                 // org: selfDetected
 
-//    d_screeningCost = DoubleVect(d_nRounds);  unused
-
-                                // Density birads indices to use for the
+                                // Breast density indices to use for the
                                 // ages of the screening rounds
-    d_indices = d_densities.indices(d_random, d_screening.ages());
+    d_indices = d_densities.indices(d_screening.ages());
 
     d_tumorInfo.cumTotalRisk(
                     d_screening.radiationRisk(
@@ -23,10 +21,10 @@ void Loop::initialize(size_t idx)
                     )
                 );
 
+    Options::instance().naturalDeathAge(
+                                    d_naturalDeathAge = naturalDeathAge());
     d_status = PRESENT;
 
-    d_options.naturalDeathAge(d_naturalDeathAge = naturalDeathAge());
-
     d_tumor.reset();
 }
 
