@@ -5,19 +5,22 @@
 
 void Loop::iterate()
 {
-    ofstream sensitivity = headerSensitivity();
+    ofstream sensitivity = headerSensitivity(); // stream to receive
+                                                // sensitivity values
 
-    if (d_scenario.seedType() == RANDOM_SEED)
-        d_random.reset(time(0));
+    if (d_scenario.seedType() == RANDOM_SEED)   
+        Random::instance().reset(time(0));
     else
         d_seed = d_scenario.seed();
 
     for (size_t idx = 0, end = d_scenario.iterations(); idx != end; ++idx)
     {
-        checkSeed();
+        checkSeed();                // reset the random generator unless
+                                    // the RANDOM_SEED mode is used
+
                                     // maybe refresh the parameters
-        d_tumorInfo.refresh(d_random, d_scenario.spread());   
-                                                   
+        d_tumorInfo.refresh(d_scenario.spread());   
+
         parameters(idx);            // write the actual parameter values,
 
         ofstream rounds = headerRounds(idx);
@@ -27,6 +30,7 @@ void Loop::iterate()
         womenLoop(idx);
 
         writeRounds(rounds);        // -> ORG/loopendout.cpp
+
         writeSensitivity(sensitivity, idx);
     }
 }
