@@ -3,7 +3,7 @@
 
 double Loop::naturalDeathAge()
 {
-    double ret = findAge(s_cumDeathProb, d_random.uniform());
+    double ret = findAge(s_cumDeathProb, Random::instance().uniform());
 
     return ret >= MAX_AGE ? MAX_AGE : ret;
 }
