@@ -5,9 +5,7 @@
 
 bool Loop::use(ModBase *modBase)
 {
-xerr("");
-
-    if (d_screening.rate().value() < d_random.uniform())
+    if (d_screening.rate().value() < Random::instance().uniform())
         return false;
 
 xerr("round " << d_round << ", count " << d_round);
@@ -47,16 +45,11 @@ xerr("round " << d_round << ", count " << d_round);
 //    return false;
 
 
-
-
-
 //     return RandomPool::instance().attendance(d_round * (modality + 1) 
 //                <= d_screening.rate().value()
 //             and
 //             ...
 
-
-
 //    (
 //        rndPoolAttendance[ screeningRound * (modality + 1) ] 
 //        <=
