@@ -7,19 +7,12 @@ void Loop::womenLoop(size_t iter)
 {
     ofstream data = headerData(iter);           
 
-    bool showAll = not d_options.specificAges() and d_options.lastCase() == 0;
+    auto const &options = Options::instance();
 
-//    d_random.reset(d_scenario.seed());
+    bool showAll = not options.specificAges() and options.lastCase() == 0;
 
-    for (
-        size_t idx = 0, 
-               end =
-                    d_options.lastCase() != 0 ? d_options.lastCase()    :
-                    d_options.specificAges()  ? 1                       :
-                                                d_scenario.nWomen();
-            idx != end; 
-                ++idx
-    )
+                                        // perform 'nCases' simulations
+    for (size_t idx = 0, end = nCases(); idx != end; ++idx)
     {
         initialize(idx);
 
