@@ -10,7 +10,6 @@ Arg::LongOption g_longOpts[] =
     Arg::LongOption{"data",         'D'},
     Arg::LongOption{"death-age",    'a'},
     Arg::LongOption{"help",         'h'},
-    Arg::LongOption{"id-base",      'i'},
     Arg::LongOption{"nCases",       'n'},
     Arg::LongOption{"one-analysis", 'o'},
     Arg::LongOption{"parameters",   'P'},
@@ -28,10 +27,12 @@ auto const *g_longEnd = g_longOpts + size(g_longOpts);
 int main(int argc, char **argv)
 try
 {
-    Arg const &arg = Arg::initialize("a:B:C:D:hi:n:oP:R:S:t:vV",
+    Arg const &arg = Arg::initialize("a:B:C:D:hn:oP:R:S:t:vV",
                                       g_longOpts, g_longEnd, argc, argv);
     arg.versionHelp(usage, Icmake::version, arg.option('o') ? 0 : 1);
 
+    Options::instance();            // construct the Options object
+
     Simulator simulator;            // construct the simulator
     simulator.run();                // and run it.
 }
