@@ -1,7 +1,8 @@
 //#define XERR
 #include "mammotomo.ih"
 
-MammoTomo::MammoTomo(string const &id, istream &in)
+MammoTomo::MammoTomo(char const *sID, uint16_t lineNr, ConfigSrc src, 
+                     string const &id, istream &in)
 :
     ModBase(id)
 {
@@ -14,7 +15,7 @@ MammoTomo::MammoTomo(string const &id, istream &in)
     for (size_t idx = 0; idx != N_SENS; ++idx)      // read sensitivities
         in >> d_sens[idx];
 
-    readSpecificities(in);
+    readSpecifications(sID, lineNr, src, id, in);
 
     setCost(cost);
 }
