@@ -3,7 +3,9 @@
 
 std::ostream &operator<<(std::ostream &out, ModBase const &modBase)
 {
-    out << "        " << modBase.id() << ":\n";
+    out << setw(8)  << ' ' << modBase.id() << ":\n" <<
+           setw(12) << ' ' << "cost:        " << modBase.d_cost << '\n';
+
     modBase.vInsert(out);
 
     return out;
