@@ -1,5 +1,8 @@
-// //#define XERR
-// #include "random.ih"
+//#define XERR
+#include "random.ih"
+
+Random Random::s_random;
+
 // 
 // mt19937 Random::s_rg{ 1 };
 // double Random::s_max = s_rg.max();
