@@ -19,7 +19,12 @@ class Random
     std::lognormal_distribution<double>     d_logNormal{ 0, 1 };
     std::exponential_distribution<double>   d_exponential{ 1 };
 
+    static Random s_random;
+
     public:
+        Random(Random const &other) = delete;
+        static Random &instance();
+
 //members
         void reset(size_t seed);
 
@@ -38,7 +43,15 @@ class Random
                                             // the time in seconds since the
                                             // epoch
                                             // (conform simrisc < V 12.00.00)
+
+    private:
+        Random() = default;
 };
 
+// static
+inline Random &Random::instance()
+{
+    return s_random;
+}
 
 #endif
