@@ -10,7 +10,8 @@ std::istream &Round::extract(istream &in)
         do
         {
             d_idx = d_modalities.size();
-            d_modalities.push_back(move(modality));
+            d_modalities.push_back(move(modality)); // 'modality' must be
+                                                    // configured
         }
         while (in >> modality);
 
