@@ -3,7 +3,7 @@
 
 std::ostream &Round::insert(std::ostream &out) const
 {
-    out << "age: " << d_age;
+    out << "age: " << static_cast<size_t>(round(d_age));
 
     for (auto const &modality: d_modalities)    
         out << ", " << modality;
