@@ -3,6 +3,8 @@
 
 void Scenario::alterOptions()
 {
+    auto &options = Options::instance();
+
     for (auto const *ptr = g_longOpts; ptr != g_longEnd; ++ptr)
     {
         auto iter = d_scenario.findID(ptr->longName());
@@ -10,8 +12,8 @@ void Scenario::alterOptions()
         if (iter == d_scenario.end())               // option not specified
             continue;
                                                     // alter the option value
-        d_options.alter(ptr->optionChar(), iter->value());
+        options.alter(ptr->optionChar(), iter->value());
     }
 
-    d_options.inspect();
+    options.inspect();
 }
