@@ -1,11 +1,8 @@
 //#define XERR
 #include "scenario.ih"
 
-Scenario::Scenario(Error &error, Options &options, ConfFile const &confFile, 
-                   istream &specs, uint16_t lineNr)
+Scenario::Scenario(ConfFile const &confFile, istream &specs, uint16_t lineNr)
 :
-    d_error(error),
-    d_options(options),
     d_confFile(confFile),
     d_scenario(specs, lineNr, Config::NoCase)   // configuration parameters
 {
