@@ -11,7 +11,7 @@ size_t Scenario::value(char const *id) const
     }
     catch (...)
     {
-        d_error(single.src, single.iter->lineNr(),     //  (
+        Error::instance()(single.src, single.iter->lineNr(),     //  (
                                     MISSING_NR) << id << "')\n";
         return string::npos;
     }
