@@ -8,7 +8,7 @@ DoubleVect Screening::radiationRisk(
                                 Uint16Vect const &indices,
                                 double beta, double eta)   // beir7 values
 {
-    double screeningRate = d_rate.d_value;
+    double screeningRate = d_rate.value();
     DoubleVect radiationRisk = DoubleVect(END_AGE, 1);
 
 //xerr("in");
@@ -23,7 +23,7 @@ xerr("screeningRate: " << screeningRate);
 
 // xerr("rndIdx: " << rndIdx << ", idx: " << idx << ", pool rnd: " << d_pool.attendance(rndIdx));
 
-        if (d_random.uniform() > screeningRate)
+        if (Random::instance().uniform() > screeningRate)
             continue;
 
 //xerr("calling beir7Err");
