@@ -1,13 +1,9 @@
 //#define XERR
 #include "screening.ih"
 
-Screening::Screening(Random &random, Scenario const &scenario)
-:
-    d_random(random)
+Screening::Screening(Scenario const &scenario)
 {
     setSystematicError(scenario);
     setAttendanceRate(scenario);
     setRounds(scenario);
-    setBeta(scenario);
-    setM(scenario);
 }
