@@ -1,13 +1,14 @@
 //#define XERR
 #include "screening.ih"
 
-void Screening::set(Spec *dest, Scenario const &scenario, char const *id)
+void Screening::set(Distribution *dest, Scenario const &scenario, 
+                    char const *id)
 {
-    auto ret = scenario.find(id);
+    auto ret = scenario.find(id);           // find the 'id' specification
 
-    if (ret.iter == scenario.end())
+    if (ret.iter == scenario.end())         // not found
     {
-        scenario.error(ret.src, 0,       // filler: ( 
+        scenario.error(ret.src, 0,          // filler: ( 
                    SPECIFICATION) << s_errorID << "')\n";
         return;
     }
