@@ -5,9 +5,11 @@
 // file. So the argument passed to this member should be the initial value
 // and not the updated value.
 
-double Spread::refresh(Random &random, double orgValue, double spread, 
+double Spread::refresh(double orgValue, double spread, 
                        uint16_t distribution)
 {
+    Random &random = Random::instance();
+
     switch (distribution)
     {
         case NORMAL:
