@@ -4,8 +4,6 @@
 
 #include "../globals/globals.h"
 
-class Random;
-
 class Spread: public Globals
 {
     protected: 
@@ -14,8 +12,7 @@ class Spread: public Globals
         // complete config file. So the argument passed to this member should
         // be the initial values and not the updated values.
 
-        static double refresh(Random &random, 
-                              double orgValue, double orgSpread, 
+        static double refresh(double orgValue, double orgSpread, 
                               uint16_t distribution);
 };
         
