@@ -4,5 +4,5 @@
 void Survival::refresh()
 {
     for (auto &vsd: d_vsd)
-        vsd.refresh(d_random);
+        vsd.refresh();
 }
