@@ -13,19 +13,15 @@
 #include "../vsd/vsd.h"
 #include "../scenario/scenario.h"
 
-class Random;
-
 class Survival: public Spread
 {
-    Random &d_random;
-
     typedef std::vector<VSD> VSDvect;
 
     VSDvect d_vsd;
     static char const s_id[];
 
     public:
-        Survival(Random &random, Scenario const &scenario);
+        Survival(Scenario const &scenario);
 
         void refresh();
         VSD const &operator[](size_t idx) const;
