@@ -1,9 +1,8 @@
 //#define XERR
 #include "survival.ih"
 
-Survival::Survival(Random &random, Scenario const &scenario)
+Survival::Survival(Scenario const &scenario)
 :
-    d_random(random),
     d_vsd(4)
 {
     string types;
