@@ -25,17 +25,19 @@ void Tumor::reset()
 
     uint16_t idx = ageGroup();
 
-    d_pSurvival = d_random.uniform();
+    Random &random = Random::instance();
+
+    d_pSurvival = random.uniform();
 
     d_startVolume = volume(d_growth.start().value());
 
-    d_doublingDays = d_random.logNormal(d_growth.group(idx).mean().value(),
-                                        d_growth.group(idx).stdDev().value());
+    d_doublingDays = random.logNormal(d_growth.group(idx).mean().value(),
+                                      d_growth.group(idx).stdDev().value());
 
     d_doublingYears = d_doublingDays / N_YEARDAYS;
 
-    d_selfDetect = d_random.logNormal(d_growth.selfMu().value(), 
-                                      d_growth.selfSigma().value());
+    d_selfDetect = random.logNormal(d_growth.selfMu().value(), 
+                                    d_growth.selfSigma().value());
 
     d_prePeriod =   d_doublingDays *
                     log(
