@@ -1,11 +1,8 @@
 //#define XERR
 #include "tumor.ih"
 
-Tumor::Tumor(Random &random, Options const &options, 
-             TumorInfo const &tumorInfo)
+Tumor::Tumor(TumorInfo const &tumorInfo)
 :
-    d_random(random),
-    d_options(options),
     d_tumorInfo(tumorInfo),
     d_growth(tumorInfo.growth()),
     d_survival(tumorInfo.survival())
