@@ -13,20 +13,22 @@ bool Tumor::tumorAge()
 //            cerr << setw(6) << value << '\n';
 //    }
 
-    d_age = findAge(d_tumorInfo.cumTotalRisk(), d_random.uniform());
+    Random &random = Random::instance();
+
+    d_age = findAge(d_tumorInfo.cumTotalRisk(), random.uniform());
 
     xerr("random tumor prob: " << rndTumor << ", age " << d_age);
 
-    d_options.tumorAge(d_age);
+    Options::instance().tumorAge(d_age);
 
     if (d_age <= MAX_AGE)
         return true;
 
     d_age = NO_TUMOR;
 
-    d_random.uniform();                 // extra calls to synchronize the
-    d_random.logNormal(0, 0);           // random generator between 
-    d_random.logNormal(0, 0);           // tumor and no tumor states
+    random.uniform();                 // extra calls to synchronize the
+    random.logNormal(0, 0);           // random generator between 
+    random.logNormal(0, 0);           // tumor and no tumor states
 
     return false;
 }
