@@ -1,12 +1,12 @@
 //#define XERR
 #include "tumorinfo.ih"
 
-void TumorInfo::refresh(Random &random, bool spread)
+void TumorInfo::refresh(bool spread)
 {
     if (not spread)
         return;
 
     d_incidence.refresh();
-    d_growth.refresh(random);
+    d_growth.refresh();
     d_survival.refresh();
 }
