@@ -1,11 +1,11 @@
 //#define XERR
 #include "tumorinfo.ih"
 
-TumorInfo::TumorInfo(Random &random, Scenario const &scenario)
+TumorInfo::TumorInfo(Scenario const &scenario)
 :
-    d_incidence(random, scenario),
+    d_incidence(scenario),
     d_beir7(scenario),
     d_growth(scenario),
-    d_survival(random, scenario)
+    d_survival(scenario)
 //    d_totalriskFile(scenario.options().totalriskFile())
 {}
