@@ -4,12 +4,13 @@
 #include <vector>
 #include <cstdint>
 #include <string>
+#include <unordered_set>
 
 typedef std::vector<double>             DoubleVect;
 typedef std::vector<DoubleVect>         DoubleVect2;
 typedef std::vector<std::string>        StringVect;
 typedef std::vector<uint16_t>           Uint16Vect;
 typedef std::vector<size_t>             SizeVect;
-
+typedef std::unordered_set<std::string> StringSet;
 
 #endif
