@@ -6,8 +6,6 @@
 #include "../enums/enums.h"
 #include "../spread/spread.h"
 
-class Random;
-
 class VSD: public Spread
 {
     friend std::istream &operator>>(std::istream &in, VSD &vsd);
@@ -19,7 +17,7 @@ class VSD: public Spread
     uint16_t d_dist = NO_DIST;          // only recognizes Normal
 
     public:
-        void refresh(Random &random);
+        void refresh();
         
         double value() const;
         double spread() const;
@@ -28,9 +26,9 @@ class VSD: public Spread
     private:
 };
 
-inline void VSD::refresh(Random &random)
+inline void VSD::refresh()
 {
-    d_value = Spread::refresh(random, d_configValue, d_spread, d_dist);
+    d_value = Spread::refresh(d_configValue, d_spread, d_dist);
 }
 
 inline double VSD::value() const
